#ifndef OBJECTS_DETECTION_OBJECTS_DETECTION_LIB_HPP
#define OBJECTS_DETECTION_OBJECTS_DETECTION_LIB_HPP

#include "objects_detection/Detection2d.hpp"

#include "video_input/calibration/CameraCalibration.hpp"

#include <boost/gil/typedefs.hpp>
#include <boost/filesystem/path.hpp>
#include <boost/program_options.hpp>
#include <boost/shared_ptr.hpp>

#include <vector>
#include <string>

namespace objects_detection {

typedef doppia::Detection2d detection_t;
typedef std::vector<detection_t> detections_t;


typedef boost::gil::rgb8c_view_t input_image_const_view_t;

/// Initialization functions
/// @{
void init_objects_detection(const boost::filesystem::path configuration_filepath);

void init_objects_detection(const boost::program_options::variables_map options);


/// Input functions
/// @{

void set_monocular_image(input_image_const_view_t &input_image);

/// @}


/// Compute functions
/// @{

/// blocking call to compute the detections
void compute();


/// @}


/// Output functions
/// @{

/// returns a copy of the current detections, will raise an exception if detections_are_ready is currently false
const detections_t get_detections();

/// @}

/// helper function to record a sequence of detections in a .data_sequence file
void record_detections(const boost::filesystem::path &image_path,
                       const detections_t &detections,
                       const int additional_border = 0);

/// helper function used by the test applications and for applications that want to parse the options by themselves
void get_options_description(boost::program_options::options_description &desc);

} // end namespace objects_detection

#endif // OBJECTS_DETECTION_OBJECTS_DETECTION_LIB_HPP
